==> tuia-advert-center-api-1.5.0-20180627.100254-47-sources.jar: cn/com/duiba/tuia/core/api/remoteservice/RemoteAdvertOrientPackageBackendService.java <==
package cn.com.duiba.tuia.core.api.remoteservice;

import java.util.List;
import java.util.Map;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.core.api.dto.AdvertOrientationPackageDto;
import cn.com.duiba.tuia.core.api.dto.req.solt.ReqAppSlotDto;
import cn.com.duiba.tuia.core.api.dto.rsp.RspAdvertChargeDto;
import cn.com.duiba.tuia.core.api.dto.rsp.RspAdvertOrientationPackageBudgetPerDayDto;
import cn.com.duiba.wolf.dubbo.DubboResult;

@AdvancedFeignClient
public interface RemoteAdvertOrientPackageBackendService {

	/**
	 * 根据广告ID查询定向投放配置包
	 * @param advertId 广告ID
	 * @return
	 * @since JDK 1.6
	 */
	DubboResult<List<AdvertOrientationPackageDto>> getAdvertOrientationPackage(Long advertId);

	/**
	 * 查询人工或者智能的投放配置包列表
	 *
	 * @param advertId    查询的广告id
	 * @param packageType 包的类型 1-人工生成的包 2-智能生成的策略包
	 * @return 投放配置包列表
	 */
	DubboResult<List<AdvertOrientationPackageDto>> getAdvertOrientationPackageList(Long advertId, Integer packageType);

	/**
	 * 开启或者暂停智能策略
	 * 1、开启时更新智能策略为开启（有效状态），并暂停人工策略（无效）
	 * 2、暂停时更新智能策略为暂停（无效状态），并开启人工策略（有效）
	 * 更新操作需要放到一个事物中
	 *
	 * @param smartStatus 智能策略状态
	 * @param advertId    广告id
	 */
	DubboResult<Boolean> updateSmartStrategyStatus(Integer smartStatus, Long advertId);

	/**
	 * 新增或者复制定向配置包
	 * @param dto 返回定向配置包的自增ID
	 * @return
	 * @since JDK 1.6
	 */
	DubboResult<Long> addAvertOrientationPackage(AdvertOrientationPackageDto dto);
	
	/**
	 * 根据定向包ID更新定向包的启用状态
	 * @param enableStatus
	 * @param id
	 * @return
	 * @since JDK 1.6
	 */
	DubboResult<Integer> updateAdvertOrientPackageEnableStatus(Integer enableStatus, Long id);
	
	/**
	 * 保存对定向配置包的修改
	 * @param dto
	 * @return
	 * @since JDK 1.6
	 */
	DubboResult<Boolean> updateAdvertOrientPackage(AdvertOrientationPackageDto dto,List<ReqAppSlotDto> reqAppSlotDtos);
	
	/**
     * 广告单价查询
     * advertOrientPackageId若为null,则根据advertId查询,不为null,两者组合查
     * @param advertId 广告ID
     * @param advertOrientPackageId 配置包ID
     * @return
     * @throws TuiaCoreException
     * @since JDK 1.6
     */
    DubboResult<List<Long>> getFeeByAdvertId(Long advertId, Long advertOrientPackageId);

	/**
	 * 广告单价查询
	 * advertOrientPackageId若为null,则根据advertId查询,不为null,两者组合查
	 * @param advertIds 广告ID
	 * @return
	 */
	DubboResult<Map<Long,Long>> getFeeByAdvertIds(List<Long> advertIds);

	/**
	 * 点击单价和转化出价查询
	 * advertOrientPackageId若为null,则根据advertId查询,不为null,两者组合查
	 * @param advertId 广告ID
	 * @param advertOrientPackageId 配置包ID
	 * @return
	 * @throws TuiaCoreException
	 * @since JDK 1.6
	 */
	DubboResult<List<RspAdvertChargeDto>> getFeeAndCpaFeeByAdvertId(Long advertId, Long advertOrientPackageId);
	
	/**
	 * 根据广告ID查询默认定向包信息
	 * @param advertId
	 * @return
	 * @throws TuiaCoreException
	 * @since JDK 1.6
	 */
	DubboResult<AdvertOrientationPackageDto> selectDefaultByAdvertId(Long advertId);
	
	/**
	 * 修改定向配置名称
	 *
	 * @param packageName 定向配置名称
	 * @param id 定向配置id
	 * @author chencheng
	 * @return
	 */
	DubboResult<Integer> updateAdvertOrientPackageName(String packageName, Long id);
	
	/**
	 * 修改定向配置每日预算
	 *
	 * @param packageName 定向配置每日预算
	 * @param id 定向配置id
	 * @author chencheng
	 * @return
	 */
	DubboResult<Integer> updateAdvertOrientPackageBudget(Long budgetPerDay, Long id);
	
	/**
     * 根据广告ID查询定向配置包每日预算
     * @param advertId 广告ID
     * @return
     * @since JDK 1.6
     */
    DubboResult<List<RspAdvertOrientationPackageBudgetPerDayDto>> getAdvertOrientationPackageBudget(Long advertId);
    
    /**
     * 根据定向配置ID查询定向投放配置
     * @param advertOrientPackageId 定向配置ID
     * @return
     * @since JDK 1.6
     */
    DubboResult<AdvertOrientationPackageDto> selectById(Long advertOrientPackageId);

	/**
	 * 根据广告ID批量查询定向信息
	 * @param advertIds
	 * @return
	 */
	DubboResult<List<AdvertOrientationPackageDto>> listAdvertOrientationPackageByAdvertIds(List<Long> advertIds);

	/**
	 * 根据包的类型查询广告配置包的预算信息列表
	 *
	 * @param advertId    广告id
	 * @param packageType 包的类型，1-人工生成的包，2-智能生成的包
	 * @return 广告配置包的预算信息列表
	 */
	List<RspAdvertOrientationPackageBudgetPerDayDto> getAdOrientationPkgBudgetList(Long advertId, Integer packageType);
	
	/**
	 * 
	 * batchUpdate:(批量更新定向配置). <br/>
	 *
	 * @author chencheng
	 * @param list
	 * @return
	 * @throws TuiaCoreException 
	 * @since JDK 1.8
	 */
	Boolean batchUpdateOrientationPackage(List<AdvertOrientationPackageDto> list);

    /**
     * 生成智能策略
     * 
     * @param list 定向包列表
     * @return true - 成功 false -失败
     */
    Boolean generateSmartOrientationPackage(List<AdvertOrientationPackageDto> list);

    void deleteSmartOrientationPackage(Long advertId);

	/**
	 * 是否超出最低 --- 只针对兑吧广告主有效
	 * @param accountId
	 * @param price
	 * @param chargeType
	 * @return
	 */
    boolean isOverBottomPrice(Long accountId,Long price,Integer chargeType);

	/**
	 * 通过广告下面的配置包列表
	 *
	 * @param advertId 广告id
	 * @return 配置包列表，不包含组装数据，只是advert_orientation_package中存在的数据
	 */
	List<AdvertOrientationPackageDto> selectOrientPkgListByAdvertId(Long advertId);

	/**
	 * 判断是否可以删除限流媒体，媒体下存在高危广告位时不可删除
	 *
	 * @param appId 限流媒体ID
	 * @param orientationPkgId 配置包ID
	 * @return true：可以删除，false：不能删除
	 */
	Boolean isDeleteLimitFlowApp(Long appId, Long orientationPkgId);

}

==> tuia-advert-center-api-1.5.9-20180810.023827-36-sources.jar: cn/com/duiba/tuia/core/api/remoteservice/RemoteAdvertOrientPackageBackendService.java <==
package cn.com.duiba.tuia.core.api.remoteservice;

import java.util.List;
import java.util.Map;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.core.api.dto.AdvertOrientationPackageDto;
import cn.com.duiba.tuia.core.api.dto.req.solt.ReqAppSlotDto;
import cn.com.duiba.tuia.core.api.dto.rsp.RspAdvertChargeDto;
import cn.com.duiba.tuia.core.api.dto.rsp.RspAdvertOrientationPackageBudgetPerDayDto;
import cn.com.duiba.wolf.dubbo.DubboResult;

@AdvancedFeignClient
public interface RemoteAdvertOrientPackageBackendService {

	/**
	 * 根据广告ID查询定向投放配置包
	 * @param advertId 广告ID
	 * @return
	 * @since JDK 1.6
	 */
	DubboResult<List<AdvertOrientationPackageDto>> getAdvertOrientationPackage(Long advertId);

	/**
	 * 查询人工或者智能的投放配置包列表
	 *
	 * @param advertId    查询的广告id
	 * @param packageType 包的类型 1-人工生成的包 2-智能生成的策略包
	 * @return 投放配置包列表
	 */
	DubboResult<List<AdvertOrientationPackageDto>> getAdvertOrientationPackageList(Long advertId, Integer packageType);

	/**
	 * 开启或者暂停智能策略
	 * 1、开启时更新智能策略为开启（有效状态），并暂停人工策略（无效）
	 * 2、暂停时更新智能策略为暂停（无效状态），并开启人工策略（有效）
	 * 更新操作需要放到一个事物中
	 *
	 * @param smartStatus 智能策略状态
	 * @param advertId    广告id
	 */
	DubboResult<Boolean> updateSmartStrategyStatus(Integer smartStatus, Long advertId);

	/**
	 * 新增或者复制定向配置包
	 * @param dto 返回定向配置包的自增ID
	 * @return
	 * @since JDK 1.6
	 */
	DubboResult<Long> addAvertOrientationPackage(AdvertOrientationPackageDto dto);
	
	/**
	 * 根据定向包ID更新定向包的启用状态
	 * @param enableStatus
	 * @param id
	 * @return
	 * @since JDK 1.6
	 */
	DubboResult<Integer> updateAdvertOrientPackageEnableStatus(Integer enableStatus, Long id,Long bugetPerDay);
	
	/**
	 * 保存对定向配置包的修改
	 * @param dto
	 * @return
	 * @since JDK 1.6
	 */
	DubboResult<Boolean> updateAdvertOrientPackage(AdvertOrientationPackageDto dto,List<ReqAppSlotDto> reqAppSlotDtos);
	
	/**
     * 广告单价查询
     * advertOrientPackageId若为null,则根据advertId查询,不为null,两者组合查
     * @param advertId 广告ID
     * @param advertOrientPackageId 配置包ID
     * @return
     * @throws TuiaCoreException
     * @since JDK 1.6
     */
    DubboResult<List<Long>> getFeeByAdvertId(Long advertId, Long advertOrientPackageId);

	/**
	 * 广告单价查询
	 * advertOrientPackageId若为null,则根据advertId查询,不为null,两者组合查
	 * @param advertIds 广告ID
	 * @return
	 */
	DubboResult<Map<Long,Long>> getFeeByAdvertIds(List<Long> advertIds);

	/**
	 * 点击单价和转化出价查询
	 * advertOrientPackageId若为null,则根据advertId查询,不为null,两者组合查
	 * @param advertId 广告ID
	 * @param advertOrientPackageId 配置包ID
	 * @return
	 * @throws TuiaCoreException
	 * @since JDK 1.6
	 */
	DubboResult<List<RspAdvertChargeDto>> getFeeAndCpaFeeByAdvertId(Long advertId, Long advertOrientPackageId);
	
	/**
	 * 根据广告ID查询默认定向包信息
	 * @param advertId
	 * @return
	 * @throws TuiaCoreException
	 * @since JDK 1.6
	 */
	DubboResult<AdvertOrientationPackageDto> selectDefaultByAdvertId(Long advertId);
	
	/**
	 * 修改定向配置名称
	 *
	 * @param packageName 定向配置名称
	 * @param id 定向配置id
	 * @author chencheng
	 * @return
	 */
	DubboResult<Integer> updateAdvertOrientPackageName(String packageName, Long id);
	
	/**
	 * 修改定向配置每日预算
	 *
	 * @param packageName 定向配置每日预算
	 * @param id 定向配置id
	 * @author chencheng
	 * @return
	 */
	DubboResult<Integer> updateAdvertOrientPackageBudget(Long budgetPerDay, Long id);
	
	/**
     * 根据广告ID查询定向配置包每日预算
     * @param advertId 广告ID
     * @return
     * @since JDK 1.6
     */
    DubboResult<List<RspAdvertOrientationPackageBudgetPerDayDto>> getAdvertOrientationPackageBudget(Long advertId);
    
    /**
     * 根据定向配置ID查询定向投放配置
     * @param advertOrientPackageId 定向配置ID
     * @return
     * @since JDK 1.6
     */
    DubboResult<AdvertOrientationPackageDto> selectById(Long advertOrientPackageId);

	/**
	 * 根据广告ID批量查询定向信息
	 * @param advertIds
	 * @return
	 */
	DubboResult<List<AdvertOrientationPackageDto>> listAdvertOrientationPackageByAdvertIds(List<Long> advertIds);

	/**
	 * 根据包的类型查询广告配置包的预算信息列表
	 *
	 * @param advertId    广告id
	 * @param packageType 包的类型，1-人工生成的包，2-智能生成的包
	 * @return 广告配置包的预算信息列表
	 */
	List<RspAdvertOrientationPackageBudgetPerDayDto> getAdOrientationPkgBudgetList(Long advertId, Integer packageType);
	
	/**
	 * 
	 * batchUpdate:(批量更新定向配置). <br/>
	 *
	 * @author chencheng
	 * @param list
	 * @return
	 * @throws TuiaCoreException 
	 * @since JDK 1.8
	 */
	Boolean batchUpdateOrientationPackage(List<AdvertOrientationPackageDto> list);

    /**
     * 生成智能策略
     * 
     * @param list 定向包列表
     * @return true - 成功 false -失败
     */
    Boolean generateSmartOrientationPackage(List<AdvertOrientationPackageDto> list);

    void deleteSmartOrientationPackage(Long advertId);

	/**
	 * 是否超出最低 --- 只针对兑吧广告主有效
	 * @param accountId
	 * @param price
	 * @param chargeType
	 * @return
	 */
    boolean isOverBottomPrice(Long accountId,Long price,Integer chargeType);

	/**
	 * 通过广告下面的配置包列表
	 *
	 * @param advertId 广告id
	 * @return 配置包列表，不包含组装数据，只是advert_orientation_package中存在的数据
	 */
	List<AdvertOrientationPackageDto> selectOrientPkgListByAdvertId(Long advertId);

	/**
	 * 判断是否可以删除限流媒体，媒体下存在高危广告位时不可删除
	 *
	 * @param appId 限流媒体ID
	 * @param orientationPkgId 配置包ID
	 * @return true：可以删除，false：不能删除
	 */
	Boolean isDeleteLimitFlowApp(Long appId, Long orientationPkgId);

}
